import"./outputWidgets.34c6efe4.js";(function(){try{var a=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(a._sentryDebugIds=a._sentryDebugIds||{},a._sentryDebugIds[e]="77afb5ae-0e67-4df1-a0fa-0de3401c6764",a._sentryDebugIdIdentifier="sentry-dbid-77afb5ae-0e67-4df1-a0fa-0de3401c6764")}catch{}})();class r{static get(e){try{const t=localStorage.getItem(e);return t&&JSON.parse(t)}catch{return null}}static set(e,t){localStorage.setItem(e,JSON.stringify(t))}static pop(e){const t=r.get(e);return r.remove(e),t}static remove(e){localStorage.removeItem(e)}}export{r as S};
//# sourceMappingURL=storage.f2a353cd.js.map
