import{d as m,ez as c,u as e,b as d,c as u,et as y,f as o,w as a,be as _,ao as p,ev as g,e as x,eB as b}from"./outputWidgets.34c6efe4.js";import"./router.5e015991.js";import"./jwt-decode.esm.74bd4619.js";import"./index.56db27ff.js";import{O as w}from"./organization.22809403.js";import{a as h}from"./asyncComputed.c2993a02.js";import{a as k}from"./Title.6b365a17.js";import{A as B}from"./index.27b4b225.js";import{A}from"./index.6cd19aa1.js";import{A as C}from"./Text.4d22598c.js";import{C as I}from"./Card.41e55738.js";import"./FormItem.87557e8f.js";import"./hasIn.7f8c0878.js";import"./storage.f2a353cd.js";import"./index.b5389b8f.js";import"./index.cf4c23b9.js";import"./record.24a52f99.js";import"./pubsub.7392fe5a.js";import"./TabPane.2459ecf5.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[r]="e93f0ea6-5c97-481d-8415-230d45de4426",t._sentryDebugIdIdentifier="sentry-dbid-e93f0ea6-5c97-481d-8415-230d45de4426")}catch{}})();const v={key:1},z={style:{display:"flex","justify-content":"flex-end","font-size":"24px"}},X=m({__name:"Billing",setup(t){const n=c().params.organizationId,{loading:l,result:f}=h(()=>w.get(n));return(D,T)=>e(l)?(d(),u(e(_),{key:0})):(d(),y("div",v,[o(e(B),{justify:"space-between",align:"center"},{default:a(()=>[o(e(k),{level:3},{default:a(()=>[p("Current plan")]),_:1}),g("",!0)]),_:1}),o(e(A),{style:{"margin-top":"0"}}),o(e(I),{style:{width:"300px"}},{default:a(()=>{var i,s;return[o(e(C),{type:"secondary"},{default:a(()=>[p("Plan")]),_:1}),x("div",z,b((s=(i=e(f))==null?void 0:i.billingMetadata)==null?void 0:s.plan),1)]}),_:1})]))}});export{X as default};
//# sourceMappingURL=Billing.b17d1335.js.map
