import"./outputWidgets.34c6efe4.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="e17f6ee7-64c1-43ed-b530-800956c4cc42",e._sentryDebugIdIdentifier="sentry-dbid-e17f6ee7-64c1-43ed-b530-800956c4cc42")}catch{}})();const d=e=>{try{return new URL(e),!0}catch{return!1}};export{d as i};
//# sourceMappingURL=url.e9fe64cc.js.map
