var o=Object.defineProperty;var i=(t,e,a)=>e in t?o(t,e,{enumerable:!0,configurable:!0,writable:!0,value:a}):t[e]=a;var n=(t,e,a)=>(i(t,typeof e!="symbol"?e+"":e,a),a);import{g as c,h as f,_ as d}from"./outputWidgets.34c6efe4.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="1b0a551d-5a8b-465c-a0b0-fa5583f6e001",t._sentryDebugIdIdentifier="sentry-dbid-1b0a551d-5a8b-465c-a0b0-fa5583f6e001")}catch{}})();const u=[{path:"/:path(.*)*",name:"player",component:()=>d(()=>import("./Player.159d861c.js"),["assets/Player.159d861c.js","assets/FormRunner.642273c5.js","assets/outputWidgets.34c6efe4.js","assets/outputWidgets.3c848cd5.css","assets/url.e9fe64cc.js","assets/storage.f2a353cd.js","assets/pubsub.7392fe5a.js","assets/jwt-decode.esm.74bd4619.js","assets/icons.54b54949.js","assets/CircularLoading.f2f9abba.js","assets/CircularLoading.f81b57b4.css","assets/PlayerNavbar.d4f780c9.js","assets/PlayerNavbar.d1d85d81.css","assets/ActionButton.1f9e2691.js","assets/ActionButton.f74e60ec.css","assets/WidgetsFrame.3f1186d8.js","assets/WidgetsFrame.97ae601d.css","assets/index.3c0f8b97.js","assets/Card.41e55738.js","assets/TabPane.2459ecf5.js","assets/hasIn.7f8c0878.js","assets/index.4b188a10.js","assets/Text.4d22598c.js","assets/Link.8b267d2f.js","assets/Title.6b365a17.js","assets/FormRunner.8ff3f1ac.css","assets/uuid.4ceb8b43.js","assets/asyncComputed.c2993a02.js","assets/Player.6fed9080.css"])}],g=c({history:f("/"),routes:u,scrollBehavior(t){if(t.hash)return{el:t.hash}}});async function w(){const t=await fetch("/_settings");if(!t.ok)throw new Error(await t.text());const e=await t.json();await r.init(e)}const s=class{constructor(e){this.config=e}static async init(e){s.instance=new s(e)}get showWatermark(){return this.config.show_watermark}get isStagingRelease(){return{}.VITE_ABSTRA_RELEASE==="staging"}get isLocal(){return location.origin.match(/http:\/\/localhost:\d+/)}};let r=s;n(r,"instance",null);export{r as S,g as a,u as r,w as s};
//# sourceMappingURL=index.4fd1c3b9.js.map
