import{t as n,b as s,et as o}from"./outputWidgets.34c6efe4.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="f6412718-b454-4f99-aabf-85ed27f471bd",e._sentryDebugIdIdentifier="sentry-dbid-f6412718-b454-4f99-aabf-85ed27f471bd")}catch{}})();const r={},a={class:"organization-settings"};function d(e,t){return s(),o("div",a,"Organization settings")}const c=n(r,[["render",d]]);export{c as default};
//# sourceMappingURL=OrganizationSettings.151e706d.js.map
