import"./outputWidgets.34c6efe4.js";(function(){try{var x=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(x._sentryDebugIds=x._sentryDebugIds||{},x._sentryDebugIds[e]="098c098b-0b81-41af-b0ec-5f41af9fab51",x._sentryDebugIdIdentifier="sentry-dbid-098c098b-0b81-41af-b0ec-5f41af9fab51")}catch{}})();const f=()=>"xxxxxxxx-xxxx-4xxx-yxxx-xxxxxxxxxxxx".replace(/[xy]/g,function(x){const e=Math.random()*16|0;return(x=="x"?e:e&3|8).toString(16)});export{f as u};
//# sourceMappingURL=uuid.4ceb8b43.js.map
