import"./outputWidgets.34c6efe4.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="85841403-32df-4a5c-9ba5-5b4a893ddcfe",e._sentryDebugIdIdentifier="sentry-dbid-85841403-32df-4a5c-9ba5-5b4a893ddcfe")}catch{}})();function s(e,n,r=!1,t=!0){const a=(t?e.toLocaleLowerCase():e).replace(/[^a-zA-Z0-9]/g,"_"),c=r?a:a.replace(/_+/g,"_");return n?c:c.replace(/_$/,"")}function l(e){var a;const r=e.toLocaleLowerCase().trim().normalize("NFD").replace(/[\u0300-\u036f]/g,""),t=/[a-z0-9]+/g,o=r.match(t);return(a=o==null?void 0:o.join("-"))!=null?a:""}export{l as a,s as n};
//# sourceMappingURL=string.6701a811.js.map
