import{a as e,A as t,B as s}from"./Text.4d22598c.js";import{A as o}from"./Link.8b267d2f.js";import{a as r,A as i}from"./Title.6b365a17.js";(function(){try{var n=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(n._sentryDebugIds=n._sentryDebugIds||{},n._sentryDebugIds[a]="27614eae-b984-443a-9d8c-9bee19435c65",n._sentryDebugIdIdentifier="sentry-dbid-27614eae-b984-443a-9d8c-9bee19435c65")}catch{}})();e.Text=t;e.Title=r;e.Paragraph=i;e.Link=o;e.Base=s;e.install=function(n){return n.component(e.name,e),n.component(e.Text.displayName,t),n.component(e.Title.displayName,r),n.component(e.Paragraph.displayName,i),n.component(e.Link.displayName,o),n};
//# sourceMappingURL=index.4b188a10.js.map
