import{N as l}from"./NavbarControls.c719ba84.js";import{d as _,ey as b,ez as y,F as g,a as v,b as c,et as h,f as e,w as s,u as a,e as k,bo as w,ao as S,c as x,eS as T,t as q}from"./outputWidgets.34c6efe4.js";import{A as C}from"./Text.4d22598c.js";import{T as I,A as o}from"./TabPane.2459ecf5.js";import{c as A}from"./index.93eb5533.js";import"./asyncComputed.c2993a02.js";import"./index.4fd1c3b9.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.d3e3a57a.js";import"./SaveButton.vue_vue_type_script_setup_true_lang.bb0bcb8e.js";import"./ant-design.ecbe403a.js";import"./index.1f3ae6b3.js";import"./Modal.20b7a2a4.js";import"./storage.f2a353cd.js";import"./Link.8b267d2f.js";import"./index.4b188a10.js";import"./Title.6b365a17.js";import"./index.134785d3.js";import"./workspaces.df94af25.js";import"./record.24a52f99.js";import"./pubsub.7392fe5a.js";import"./url.e9fe64cc.js";import"./popupNotifcation.58513ebb.js";import"./CircularLoading.f2f9abba.js";import"./icons.54b54949.js";import"./index.27b4b225.js";import"./hasIn.7f8c0878.js";(function(){try{var r=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(r._sentryDebugIds=r._sentryDebugIds||{},r._sentryDebugIds[t]="8c3f0125-1c9a-4a61-aece-c9f9660f20bf",r._sentryDebugIdIdentifier="sentry-dbid-8c3f0125-1c9a-4a61-aece-c9f9660f20bf")}catch{}})();const B={class:"content"},D=_({__name:"Settings",setup(r){const t=b(),n=y();function m(){t.push({name:"home"})}const p=g(()=>{switch(n.name){case"settingsStyle":return"style";case"settingsSidebar":return"sidebar";case"settingsRequirements":return"requirements";default:return}});function u(i){switch(i){case"style":t.push({name:"settingsStyle"});break;case"sidebar":t.push({name:"settingsSidebar"});break;case"requirements":t.push({name:"settingsRequirements"});break}}return(i,N)=>{const d=v("router-view");return c(),h(w,null,[e(a(A),{style:{padding:"5px 25px"},onBack:m},{extra:s(()=>[e(l,{"show-v-s-code-button":"","show-save-button":""})]),avatar:s(()=>[e(a(C),null,{default:s(()=>[S("Settings")]),_:1})]),footer:s(()=>[e(a(I),{"active-key":p.value,onChange:u},{default:s(()=>[e(a(o),{key:"style",tab:"Style"}),e(a(o),{key:"sidebar",tab:"Sidebar"}),e(a(o),{key:"requirements",tab:"Requirements"})]),_:1},8,["active-key"])]),_:1}),k("div",B,[e(d,null,{default:s(({Component:f})=>[(c(),x(T(f)))]),_:1})])],64)}}});const oe=q(D,[["__scopeId","data-v-772f4b10"]]);export{oe as default};
//# sourceMappingURL=Settings.ab3761cb.js.map
