import{cu as f}from"./outputWidgets.34c6efe4.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},d=new Error().stack;d&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[d]="bf3401fc-9fd2-40da-9542-4ad07742fb4c",e._sentryDebugIdIdentifier="sentry-dbid-bf3401fc-9fd2-40da-9542-4ad07742fb4c")}catch{}})();const o=(e,d)=>{f.error({message:e,description:d})};export{o as p};
//# sourceMappingURL=popupNotifcation.58513ebb.js.map
