import{C as n,A as d}from"./CollapsePanel.919bee02.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},f=new Error().stack;f&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[f]="81b56ff9-d9fb-473e-b64a-9d85fd94db35",e._sentryDebugIdIdentifier="sentry-dbid-81b56ff9-d9fb-473e-b64a-9d85fd94db35")}catch{}})();n.Panel=d;n.install=function(e){return e.component(n.name,n),e.component(d.name,d),e};
//# sourceMappingURL=index.a30267b5.js.map
