import{Q as s}from"./outputWidgets.34c6efe4.js";import{c as i,d as f}from"./index.8a51e439.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},c=new Error().stack;c&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[c]="4e6c3af4-d99b-4c04-97f4-4f99a86031fa",e._sentryDebugIdIdentifier="sentry-dbid-4e6c3af4-d99b-4c04-97f4-4f99a86031fa")}catch{}})();const{DatePicker:n,WeekPicker:r,MonthPicker:t,YearPicker:d,TimePicker:m,QuarterPicker:a,RangePicker:o}=i(f),b=s(n,{WeekPicker:r,MonthPicker:t,YearPicker:d,RangePicker:o,TimePicker:m,QuarterPicker:a,install:e=>(e.component(n.name,n),e.component(o.name,o),e.component(t.name,t),e.component(r.name,r),e.component(a.name,a),e)});export{b as D,t as M,a as Q,o as R,r as W};
//# sourceMappingURL=dayjs.0a55a5c6.js.map
