import{F as t}from"./Form.3d80c841.js";import{aJ as r,cj as n}from"./outputWidgets.34c6efe4.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="d459c6ec-419f-4315-bd37-9b21f1476cac",e._sentryDebugIdIdentifier="sentry-dbid-d459c6ec-419f-4315-bd37-9b21f1476cac")}catch{}})();t.useInjectFormItemContext=r;t.ItemRest=n;t.install=function(e){return e.component(t.name,t),e.component(t.Item.name,t.Item),e.component(n.name,n),e};
//# sourceMappingURL=index.714418f3.js.map
